#include <cstdio>
#include <cmath>

/* cost weights */
const double AoW = 1;
const double RiW = 1e5;
const double WcW = 1;
const double CiW = -1e-17;
const double RoW = -1e-1;

struct OpAmp {
    OpAmp() {};
    OpAmp(const double* p) {
        Ri = p[0];
        Ci = p[1];
        Ro = p[2];
        Ao = p[3];
        Wc = p[4];
        update();
    }

    void load_file(FILE* f) {
        fscanf(f, "%lf %lf %lf %lf %lf", &Ri, &Ci, &Ro, &Ao, &Wc);
        update();
    }

    void update() {
        Ri *= 1e6;             // MOhms
        Ci *= 1e-12;           // pF
        Ro *= 1;               // Ohms
        Ao  = pow(10, (Ao/20));// dB
        Wc *= 1e3*M_PI;        // k pi Hz
    }

    double cost() {
        return Ao/AoW + (Ri/RiW) + Wc/WcW + Ci/CiW + Ro/RoW;
    }

    double Ri, Ci, Ro, Ao, Wc;
};
